==> bivariate_0.4.1.tar.gz: bivariate/inst/doc/bivariate.R <==
### R code from vignette source 'bivariate.Rnw'

###################################################
### code chunk number 1: bivariate.Rnw:34-39
###################################################
options(continue=" ")
options(SweaveHooks=list(fig=function()
par(mar=c(4.1, 4.1, 2.6, 1.6), cex=0.7, cex.main=1)))

set.seed (1)


###################################################
### code chunk number 2: bivariate.Rnw:97-100
###################################################
library (intoo)
library (bivariate)
library (MASS)


###################################################
### code chunk number 3: bivariate.Rnw:111-112
###################################################
f = dubvpmf (1, 4, 1, 4)


###################################################
### code chunk number 4: bivariate.Rnw:120-121
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 5: bivariate.Rnw:128-130
###################################################
getOption("SweaveHooks")[["fig"]]()
F = dubvcdf (1, 4, 1, 4)
plot (F, TRUE)


###################################################
### code chunk number 6: bivariate.Rnw:136-137
###################################################
f (1, 1)


###################################################
### code chunk number 7: bivariate.Rnw:159-161
###################################################
getOption("SweaveHooks")[["fig"]]()
f = bnbvpmf (0.5, 0.5, 20)
plot (f)


###################################################
### code chunk number 8: bivariate.Rnw:163-164
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 9: bivariate.Rnw:171-173
###################################################
getOption("SweaveHooks")[["fig"]]()
F = bnbvcdf (0.5, 0.5, 20)
plot (F, TRUE)


###################################################
### code chunk number 10: bivariate.Rnw:202-204
###################################################
getOption("SweaveHooks")[["fig"]]()
f = pbvpmf.2 (8, 8, 2)
plot (f)


###################################################
### code chunk number 11: bivariate.Rnw:206-207
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 12: bivariate.Rnw:214-216
###################################################
getOption("SweaveHooks")[["fig"]]()
F = pbvcdf.2 (8, 8, 2)
plot (F, TRUE)


###################################################
### code chunk number 13: bivariate.Rnw:226-229
###################################################
z = matrix (sample (1:16), 4, 4) / 136
rownames (z) = colnames (z) = c ("A", "B", "C", "D")
z


###################################################
### code chunk number 14: bivariate.Rnw:233-235
###################################################
getOption("SweaveHooks")[["fig"]]()
f = cbvpmf (z)
plot (f, TRUE)


###################################################
### code chunk number 15: bivariate.Rnw:240-242
###################################################
f (1, 2)
f ("A", "B")


###################################################
### code chunk number 16: bivariate.Rnw:253-255
###################################################
getOption("SweaveHooks")[["fig"]]()
f = cubvpdf (0, 2, 0, 2)
plot (f, TRUE)


###################################################
### code chunk number 17: bivariate.Rnw:262-263
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 18: bivariate.Rnw:274-275
###################################################
f = nbvpdf (0, 0, 1, 1, 0)


###################################################
### code chunk number 19: bivariate.Rnw:279-280
###################################################
f


###################################################
### code chunk number 20: bivariate.Rnw:286-287
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f)


###################################################
### code chunk number 21: bivariate.Rnw:290-291
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 22: bivariate.Rnw:296-297
###################################################
F = nbvcdf (0, 0, 1, 1, 0)


###################################################
### code chunk number 23: bivariate.Rnw:303-304
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F)


###################################################
### code chunk number 24: bivariate.Rnw:307-308
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 25: bivariate.Rnw:326-328
###################################################
getOption("SweaveHooks")[["fig"]]()
f = bmbvpdf (3.5, 0, 1, 1, 6.5, 0, 1, 1)
plot (f, npoints=40)


###################################################
### code chunk number 26: bivariate.Rnw:331-332
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE, npoints=40)


###################################################
### code chunk number 27: bivariate.Rnw:339-341
###################################################
getOption("SweaveHooks")[["fig"]]()
F = bmbvcdf (3.5, 0, 1, 1, 6.5, 0, 1, 1)
plot (F, npoints=40)


###################################################
### code chunk number 28: bivariate.Rnw:344-345
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE, npoints=40)


###################################################
### code chunk number 29: bivariate.Rnw:359-361
###################################################
getOption("SweaveHooks")[["fig"]]()
f = dtvpdf (2, 4, 6)
plot (f)


###################################################
### code chunk number 30: bivariate.Rnw:364-365
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 31: bivariate.Rnw:372-373
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE, log=TRUE)


###################################################
### code chunk number 32: bivariate.Rnw:387-389
###################################################
data ("geyser")
attach (geyser)


###################################################
### code chunk number 33: bivariate.Rnw:392-393
###################################################
f = kbvpdf (duration, waiting, 0.7, 7)


###################################################
### code chunk number 34: bivariate.Rnw:398-399
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, xlab="duration", ylab="waiting")


###################################################
### code chunk number 35: bivariate.Rnw:402-403
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE, xlab="duration", ylab="waiting")


###################################################
### code chunk number 36: bivariate.Rnw:407-408
###################################################
detach (geyser)


###################################################
### code chunk number 37: bivariate.Rnw:416-418
###################################################
x = rnorm (20)
y = rnorm (20)


###################################################
### code chunk number 38: bivariate.Rnw:422-424
###################################################
getOption("SweaveHooks")[["fig"]]()
F = ebvcdf (x, y)
plot (F)


###################################################
### code chunk number 39: bivariate.Rnw:427-428
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 40: bivariate.Rnw:465-467
###################################################
f1 = nbvpdf (0, 0, 1, 1, 0)
f1 %$% matrix.variances


###################################################
### code chunk number 41: bivariate.Rnw:470-471
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f1, all=TRUE)


###################################################
### code chunk number 42: bivariate.Rnw:478-480
###################################################
f2 = nbvpdf (0, 0, 1, 1, 0.75)
f2 %$% matrix.variances


###################################################
### code chunk number 43: bivariate.Rnw:483-484
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f2, all=TRUE)


###################################################
### code chunk number 44: bivariate.Rnw:491-493
###################################################
f3 = nbvpdf (0, 0, 1, 1, -0.75)
f3 %$% matrix.variances


###################################################
### code chunk number 45: bivariate.Rnw:496-497
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f3, all=TRUE)


###################################################
### code chunk number 46: bivariate.Rnw:510-511
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (dtvpdf (1, 1, 1), TRUE)


###################################################
### code chunk number 47: bivariate.Rnw:518-519
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (dtvpdf (2, 2, 2), TRUE)


###################################################
### code chunk number 48: bivariate.Rnw:526-527
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (dtvpdf (0.5, 0.5, 0.5), TRUE)

==> bivariate_0.5.0.tar.gz: bivariate/inst/doc/bivariate.R <==
### R code from vignette source 'bivariate.Rnw'

###################################################
### code chunk number 1: bivariate.Rnw:41-46
###################################################
options(continue="   ")
options(SweaveHooks=list(fig=function()
par(mar=c(4.1, 4.1, 1.35, 1.6), cex=0.7, cex.main=1)))

set.seed (1)


###################################################
### code chunk number 2: bivariate.Rnw:98-102
###################################################
library (intoo)
library (barsurf)
library (bivariate)
library (MASS)


###################################################
### code chunk number 3: bivariate.Rnw:109-110
###################################################
set.bs.options (rendering.style="e")


###################################################
### code chunk number 4: bivariate.Rnw:118-119
###################################################
set.bs.theme ("gold")


###################################################
### code chunk number 5: bivariate.Rnw:137-139
###################################################
f <- dubvpmf (1, 1, 6, 6)
F <- dubvcdf (1, 1, 6, 6)


###################################################
### code chunk number 6: bivariate.Rnw:145-146
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 7: bivariate.Rnw:148-149
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 8: bivariate.Rnw:158-160
###################################################
f (2, 4)
F (2, 4)


###################################################
### code chunk number 9: bivariate.Rnw:168-172
###################################################
d.unif.pmf.eval <- function (x, a, b)    #x ignored
    1 / (b - a + 1)
d.unif.cdf.eval <- function (x, a, b)    #x used
    (x - a + 1) / (b - a + 1)


###################################################
### code chunk number 10: bivariate.Rnw:175-177
###################################################
d.unif.pmf.eval (2, 1, 6) * d.unif.pmf.eval (4, 1, 6)
d.unif.cdf.eval (2, 1, 6) * d.unif.cdf.eval (4, 1, 6)


###################################################
### code chunk number 11: bivariate.Rnw:201-203
###################################################
f <- bnbvpmf (0.5, 0.25, 10)
F <- bnbvcdf (0.5, 0.25, 10)


###################################################
### code chunk number 12: bivariate.Rnw:210-211
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 13: bivariate.Rnw:213-214
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 14: bivariate.Rnw:225-226
###################################################
set.bs.theme ("blue")


###################################################
### code chunk number 15: bivariate.Rnw:253-255
###################################################
f <- pbvpmf.2 (8, 8, 2)
F <- pbvcdf.2 (8, 8, 2)


###################################################
### code chunk number 16: bivariate.Rnw:261-262
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f)


###################################################
### code chunk number 17: bivariate.Rnw:264-265
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 18: bivariate.Rnw:267-268
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F)


###################################################
### code chunk number 19: bivariate.Rnw:274-275
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 20: bivariate.Rnw:289-293
###################################################
h <- sample (1:24)
h <- matrix (h, 6, 4)
rownames (h) <- LETTERS [1:6]
colnames (h) <- letters [1:4]


###################################################
### code chunk number 21: bivariate.Rnw:296-297
###################################################
h


###################################################
### code chunk number 22: bivariate.Rnw:300-301
###################################################
f <- cbvpmf (h)


###################################################
### code chunk number 23: bivariate.Rnw:308-309
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f)


###################################################
### code chunk number 24: bivariate.Rnw:311-313
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE,
    arrows=FALSE)


###################################################
### code chunk number 25: bivariate.Rnw:319-321
###################################################
f (2, 4)
f ("B", "d")


###################################################
### code chunk number 26: bivariate.Rnw:327-328
###################################################
set.bs.theme ("gold")


###################################################
### code chunk number 27: bivariate.Rnw:338-340
###################################################
f <- cubvpdf (0, 0, 2, 2)
F <- cubvcdf (0, 0, 2, 2)


###################################################
### code chunk number 28: bivariate.Rnw:346-347
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 29: bivariate.Rnw:353-354
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 30: bivariate.Rnw:363-364
###################################################
set.bs.theme ("blue")


###################################################
### code chunk number 31: bivariate.Rnw:376-378
###################################################
f <- nbvpdf (0, 0, 1, 1, 0)
F <- nbvcdf (0, 0, 1, 1, 0)


###################################################
### code chunk number 32: bivariate.Rnw:385-386
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f)


###################################################
### code chunk number 33: bivariate.Rnw:388-389
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 34: bivariate.Rnw:395-396
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F)


###################################################
### code chunk number 35: bivariate.Rnw:398-399
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE)


###################################################
### code chunk number 36: bivariate.Rnw:415-421
###################################################
f <- bmbvpdf (
    3.5, 0, 1, 1,    #first component distribution
    6.5, 0, 1, 1)    #second component distribution
F <- bmbvcdf (
    3.5, 0, 1, 1,    #first component distribution
    6.5, 0, 1, 1)    #second component distribution


###################################################
### code chunk number 37: bivariate.Rnw:427-428
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f)


###################################################
### code chunk number 38: bivariate.Rnw:434-436
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE,
    arrows = c (FALSE, TRUE), xat = c (3.5, 6.5) )


###################################################
### code chunk number 39: bivariate.Rnw:438-439
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F)


###################################################
### code chunk number 40: bivariate.Rnw:445-447
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (F, TRUE,
    arrows = c (FALSE, TRUE), xat = c (3.5, 6.5) )


###################################################
### code chunk number 41: bivariate.Rnw:464-465
###################################################
f <- dtvpdf (2, 4, 6)


###################################################
### code chunk number 42: bivariate.Rnw:472-473
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f)


###################################################
### code chunk number 43: bivariate.Rnw:475-476
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE)


###################################################
### code chunk number 44: bivariate.Rnw:484-485
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f, TRUE, log=TRUE)


###################################################
### code chunk number 45: bivariate.Rnw:505-507
###################################################
data ("geyser")
attach (geyser)


###################################################
### code chunk number 46: bivariate.Rnw:510-511
###################################################
fh <- kbvpdf (duration, waiting, 0.7, 7)


###################################################
### code chunk number 47: bivariate.Rnw:518-520
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (fh,
    xlab="duration", ylab="waiting")


###################################################
### code chunk number 48: bivariate.Rnw:523-525
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (fh, TRUE,
    xlab="duration", ylab="waiting")


###################################################
### code chunk number 49: bivariate.Rnw:529-530
###################################################
detach (geyser)


###################################################
### code chunk number 50: bivariate.Rnw:551-553
###################################################
x <- rnorm (20)
y <- rnorm (20)


###################################################
### code chunk number 51: bivariate.Rnw:556-557
###################################################
Fh <- ebvcdf (x, y)


###################################################
### code chunk number 52: bivariate.Rnw:563-565
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (Fh,
    xyrel="f")


###################################################
### code chunk number 53: bivariate.Rnw:571-572
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (Fh, TRUE)


###################################################
### code chunk number 54: bivariate.Rnw:608-610
###################################################
f1 <- nbvpdf (0, 0, 1, 1, 0)
f1 %$% matrix.variances


###################################################
### code chunk number 55: bivariate.Rnw:614-615
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f1, all=TRUE, n=20)


###################################################
### code chunk number 56: bivariate.Rnw:622-624
###################################################
f2 <- nbvpdf (0, 0, 1, 1, 0.75)
f2 %$% matrix.variances


###################################################
### code chunk number 57: bivariate.Rnw:629-630
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f2, all=TRUE, n=20)


###################################################
### code chunk number 58: bivariate.Rnw:636-638
###################################################
f3 <- nbvpdf (0, 0, 1, 1, -0.75)
f3 %$% matrix.variances


###################################################
### code chunk number 59: bivariate.Rnw:643-644
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (f3, all=TRUE, n=20)


###################################################
### code chunk number 60: bivariate.Rnw:657-658
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (dtvpdf (1, 1, 1), TRUE)


###################################################
### code chunk number 61: bivariate.Rnw:665-666
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (dtvpdf (2, 2, 2), TRUE)


###################################################
### code chunk number 62: bivariate.Rnw:674-675
###################################################
getOption("SweaveHooks")[["fig"]]()
plot (dtvpdf (0.5, 0.5, 0.5), TRUE)
